Simd

Struct Simd 

#[repr(transparent)]
pub struct Simd<N>(pub N);
An Simd structure that implements all the relevant traits from num an simba.

This is needed to overcome the orphan rules.

Tuple Fields

0: N

Implementations

Source

impl Simd<f32x1>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: f32) -> Self

Source

impl Simd<f32x1>

pub fn from_slice_unaligned(slice: &[f32]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<f32x2>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: f32, _1: f32) -> Self

Source

impl Simd<f32x2>

pub fn from_slice_unaligned(slice: &[f32]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<f32x4>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: f32, _1: f32, _2: f32, _3: f32) -> Self

Source

impl Simd<f32x4>

pub fn from_slice_unaligned(slice: &[f32]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<f32x8>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: f32, _1: f32, _2: f32, _3: f32, _4: f32, _5: f32, _6: f32, _7: f32, ) -> Self

Source

impl Simd<f32x8>

pub fn from_slice_unaligned(slice: &[f32]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<f32x16>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: f32, _1: f32, _2: f32, _3: f32, _4: f32, _5: f32, _6: f32, _7: f32, _8: f32, _9: f32, _10: f32, _11: f32, _12: f32, _13: f32, _14: f32, _15: f32, ) -> Self

Source

impl Simd<f32x16>

pub fn from_slice_unaligned(slice: &[f32]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<f64x1>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: f64) -> Self

Source

impl Simd<f64x1>

pub fn from_slice_unaligned(slice: &[f64]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<f64x2>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: f64, _1: f64) -> Self

Source

impl Simd<f64x2>

pub fn from_slice_unaligned(slice: &[f64]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<f64x4>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: f64, _1: f64, _2: f64, _3: f64) -> Self

Source

impl Simd<f64x4>

pub fn from_slice_unaligned(slice: &[f64]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<f64x8>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: f64, _1: f64, _2: f64, _3: f64, _4: f64, _5: f64, _6: f64, _7: f64, ) -> Self

Source

impl Simd<f64x8>

pub fn from_slice_unaligned(slice: &[f64]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i16x1>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: i16) -> Self

Source

impl Simd<i16x1>

pub fn from_slice_unaligned(slice: &[i16]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i16x2>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: i16, _1: i16) -> Self

Source

impl Simd<i16x2>

pub fn from_slice_unaligned(slice: &[i16]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i16x4>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: i16, _1: i16, _2: i16, _3: i16) -> Self

Source

impl Simd<i16x4>

pub fn from_slice_unaligned(slice: &[i16]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i16x8>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: i16, _1: i16, _2: i16, _3: i16, _4: i16, _5: i16, _6: i16, _7: i16, ) -> Self

Source

impl Simd<i16x8>

pub fn from_slice_unaligned(slice: &[i16]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i16x16>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: i16, _1: i16, _2: i16, _3: i16, _4: i16, _5: i16, _6: i16, _7: i16, _8: i16, _9: i16, _10: i16, _11: i16, _12: i16, _13: i16, _14: i16, _15: i16, ) -> Self

Source

impl Simd<i16x16>

pub fn from_slice_unaligned(slice: &[i16]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i16x32>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: i16, _1: i16, _2: i16, _3: i16, _4: i16, _5: i16, _6: i16, _7: i16, _8: i16, _9: i16, _10: i16, _11: i16, _12: i16, _13: i16, _14: i16, _15: i16, _16: i16, _17: i16, _18: i16, _19: i16, _20: i16, _21: i16, _22: i16, _23: i16, _24: i16, _25: i16, _26: i16, _27: i16, _28: i16, _29: i16, _30: i16, _31: i16, ) -> Self

Source

impl Simd<i16x32>

pub fn from_slice_unaligned(slice: &[i16]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i32x1>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: i32) -> Self

Source

impl Simd<i32x1>

pub fn from_slice_unaligned(slice: &[i32]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i32x2>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: i32, _1: i32) -> Self

Source

impl Simd<i32x2>

pub fn from_slice_unaligned(slice: &[i32]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i32x4>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: i32, _1: i32, _2: i32, _3: i32) -> Self

Source

impl Simd<i32x4>

pub fn from_slice_unaligned(slice: &[i32]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i32x8>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: i32, _1: i32, _2: i32, _3: i32, _4: i32, _5: i32, _6: i32, _7: i32, ) -> Self

Source

impl Simd<i32x8>

pub fn from_slice_unaligned(slice: &[i32]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i32x16>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: i32, _1: i32, _2: i32, _3: i32, _4: i32, _5: i32, _6: i32, _7: i32, _8: i32, _9: i32, _10: i32, _11: i32, _12: i32, _13: i32, _14: i32, _15: i32, ) -> Self

Source

impl Simd<i32x16>

pub fn from_slice_unaligned(slice: &[i32]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i64x1>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: i64) -> Self

Source

impl Simd<i64x1>

pub fn from_slice_unaligned(slice: &[i64]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i64x2>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: i64, _1: i64) -> Self

Source

impl Simd<i64x2>

pub fn from_slice_unaligned(slice: &[i64]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i64x4>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: i64, _1: i64, _2: i64, _3: i64) -> Self

Source

impl Simd<i64x4>

pub fn from_slice_unaligned(slice: &[i64]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i64x8>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: i64, _1: i64, _2: i64, _3: i64, _4: i64, _5: i64, _6: i64, _7: i64, ) -> Self

Source

impl Simd<i64x8>

pub fn from_slice_unaligned(slice: &[i64]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i8x1>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: i8) -> Self

Source

impl Simd<i8x1>

pub fn from_slice_unaligned(slice: &[i8]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i8x2>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: i8, _1: i8) -> Self

Source

impl Simd<i8x2>

pub fn from_slice_unaligned(slice: &[i8]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i8x4>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: i8, _1: i8, _2: i8, _3: i8) -> Self

Source

impl Simd<i8x4>

pub fn from_slice_unaligned(slice: &[i8]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i8x8>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: i8, _1: i8, _2: i8, _3: i8, _4: i8, _5: i8, _6: i8, _7: i8, ) -> Self

Source

impl Simd<i8x8>

pub fn from_slice_unaligned(slice: &[i8]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i8x16>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: i8, _1: i8, _2: i8, _3: i8, _4: i8, _5: i8, _6: i8, _7: i8, _8: i8, _9: i8, _10: i8, _11: i8, _12: i8, _13: i8, _14: i8, _15: i8, ) -> Self

Source

impl Simd<i8x16>

pub fn from_slice_unaligned(slice: &[i8]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i8x32>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: i8, _1: i8, _2: i8, _3: i8, _4: i8, _5: i8, _6: i8, _7: i8, _8: i8, _9: i8, _10: i8, _11: i8, _12: i8, _13: i8, _14: i8, _15: i8, _16: i8, _17: i8, _18: i8, _19: i8, _20: i8, _21: i8, _22: i8, _23: i8, _24: i8, _25: i8, _26: i8, _27: i8, _28: i8, _29: i8, _30: i8, _31: i8, ) -> Self

Source

impl Simd<i8x32>

pub fn from_slice_unaligned(slice: &[i8]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<i8x64>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: i8, _1: i8, _2: i8, _3: i8, _4: i8, _5: i8, _6: i8, _7: i8, _8: i8, _9: i8, _10: i8, _11: i8, _12: i8, _13: i8, _14: i8, _15: i8, _16: i8, _17: i8, _18: i8, _19: i8, _20: i8, _21: i8, _22: i8, _23: i8, _24: i8, _25: i8, _26: i8, _27: i8, _28: i8, _29: i8, _30: i8, _31: i8, _32: i8, _33: i8, _34: i8, _35: i8, _36: i8, _37: i8, _38: i8, _39: i8, _40: i8, _41: i8, _42: i8, _43: i8, _44: i8, _45: i8, _46: i8, _47: i8, _48: i8, _49: i8, _50: i8, _51: i8, _52: i8, _53: i8, _54: i8, _55: i8, _56: i8, _57: i8, _58: i8, _59: i8, _60: i8, _61: i8, _62: i8, _63: i8, ) -> Self

Source

impl Simd<i8x64>

pub fn from_slice_unaligned(slice: &[i8]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<isizex1>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: isize) -> Self

Source

impl Simd<isizex1>

pub fn from_slice_unaligned(slice: &[isize]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<isizex2>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: isize, _1: isize) -> Self

Source

impl Simd<isizex2>

pub fn from_slice_unaligned(slice: &[isize]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<isizex4>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: isize, _1: isize, _2: isize, _3: isize) -> Self

Source

impl Simd<isizex4>

pub fn from_slice_unaligned(slice: &[isize]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<isizex8>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: isize, _1: isize, _2: isize, _3: isize, _4: isize, _5: isize, _6: isize, _7: isize, ) -> Self

Source

impl Simd<isizex8>

pub fn from_slice_unaligned(slice: &[isize]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u16x1>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: u16) -> Self

Source

impl Simd<u16x1>

pub fn from_slice_unaligned(slice: &[u16]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u16x2>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: u16, _1: u16) -> Self

Source

impl Simd<u16x2>

pub fn from_slice_unaligned(slice: &[u16]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u16x4>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: u16, _1: u16, _2: u16, _3: u16) -> Self

Source

impl Simd<u16x4>

pub fn from_slice_unaligned(slice: &[u16]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u16x8>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: u16, _1: u16, _2: u16, _3: u16, _4: u16, _5: u16, _6: u16, _7: u16, ) -> Self

Source

impl Simd<u16x8>

pub fn from_slice_unaligned(slice: &[u16]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u16x16>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: u16, _1: u16, _2: u16, _3: u16, _4: u16, _5: u16, _6: u16, _7: u16, _8: u16, _9: u16, _10: u16, _11: u16, _12: u16, _13: u16, _14: u16, _15: u16, ) -> Self

Source

impl Simd<u16x16>

pub fn from_slice_unaligned(slice: &[u16]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u16x32>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: u16, _1: u16, _2: u16, _3: u16, _4: u16, _5: u16, _6: u16, _7: u16, _8: u16, _9: u16, _10: u16, _11: u16, _12: u16, _13: u16, _14: u16, _15: u16, _16: u16, _17: u16, _18: u16, _19: u16, _20: u16, _21: u16, _22: u16, _23: u16, _24: u16, _25: u16, _26: u16, _27: u16, _28: u16, _29: u16, _30: u16, _31: u16, ) -> Self

Source

impl Simd<u16x32>

pub fn from_slice_unaligned(slice: &[u16]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u32x1>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: u32) -> Self

Source

impl Simd<u32x1>

pub fn from_slice_unaligned(slice: &[u32]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u32x2>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: u32, _1: u32) -> Self

Source

impl Simd<u32x2>

pub fn from_slice_unaligned(slice: &[u32]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u32x4>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: u32, _1: u32, _2: u32, _3: u32) -> Self

Source

impl Simd<u32x4>

pub fn from_slice_unaligned(slice: &[u32]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u32x8>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: u32, _1: u32, _2: u32, _3: u32, _4: u32, _5: u32, _6: u32, _7: u32, ) -> Self

Source

impl Simd<u32x8>

pub fn from_slice_unaligned(slice: &[u32]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u32x16>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: u32, _1: u32, _2: u32, _3: u32, _4: u32, _5: u32, _6: u32, _7: u32, _8: u32, _9: u32, _10: u32, _11: u32, _12: u32, _13: u32, _14: u32, _15: u32, ) -> Self

Source

impl Simd<u32x16>

pub fn from_slice_unaligned(slice: &[u32]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u64x1>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: u64) -> Self

Source

impl Simd<u64x1>

pub fn from_slice_unaligned(slice: &[u64]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u64x2>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: u64, _1: u64) -> Self

Source

impl Simd<u64x2>

pub fn from_slice_unaligned(slice: &[u64]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u64x4>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: u64, _1: u64, _2: u64, _3: u64) -> Self

Source

impl Simd<u64x4>

pub fn from_slice_unaligned(slice: &[u64]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u64x8>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: u64, _1: u64, _2: u64, _3: u64, _4: u64, _5: u64, _6: u64, _7: u64, ) -> Self

Source

impl Simd<u64x8>

pub fn from_slice_unaligned(slice: &[u64]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u8x1>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: u8) -> Self

Source

impl Simd<u8x1>

pub fn from_slice_unaligned(slice: &[u8]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u8x2>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: u8, _1: u8) -> Self

Source

impl Simd<u8x2>

pub fn from_slice_unaligned(slice: &[u8]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u8x4>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: u8, _1: u8, _2: u8, _3: u8) -> Self

Source

impl Simd<u8x4>

pub fn from_slice_unaligned(slice: &[u8]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u8x8>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: u8, _1: u8, _2: u8, _3: u8, _4: u8, _5: u8, _6: u8, _7: u8, ) -> Self

Source

impl Simd<u8x8>

pub fn from_slice_unaligned(slice: &[u8]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u8x16>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: u8, _1: u8, _2: u8, _3: u8, _4: u8, _5: u8, _6: u8, _7: u8, _8: u8, _9: u8, _10: u8, _11: u8, _12: u8, _13: u8, _14: u8, _15: u8, ) -> Self

Source

impl Simd<u8x16>

pub fn from_slice_unaligned(slice: &[u8]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u8x32>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: u8, _1: u8, _2: u8, _3: u8, _4: u8, _5: u8, _6: u8, _7: u8, _8: u8, _9: u8, _10: u8, _11: u8, _12: u8, _13: u8, _14: u8, _15: u8, _16: u8, _17: u8, _18: u8, _19: u8, _20: u8, _21: u8, _22: u8, _23: u8, _24: u8, _25: u8, _26: u8, _27: u8, _28: u8, _29: u8, _30: u8, _31: u8, ) -> Self

Source

impl Simd<u8x32>

pub fn from_slice_unaligned(slice: &[u8]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<u8x64>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: u8, _1: u8, _2: u8, _3: u8, _4: u8, _5: u8, _6: u8, _7: u8, _8: u8, _9: u8, _10: u8, _11: u8, _12: u8, _13: u8, _14: u8, _15: u8, _16: u8, _17: u8, _18: u8, _19: u8, _20: u8, _21: u8, _22: u8, _23: u8, _24: u8, _25: u8, _26: u8, _27: u8, _28: u8, _29: u8, _30: u8, _31: u8, _32: u8, _33: u8, _34: u8, _35: u8, _36: u8, _37: u8, _38: u8, _39: u8, _40: u8, _41: u8, _42: u8, _43: u8, _44: u8, _45: u8, _46: u8, _47: u8, _48: u8, _49: u8, _50: u8, _51: u8, _52: u8, _53: u8, _54: u8, _55: u8, _56: u8, _57: u8, _58: u8, _59: u8, _60: u8, _61: u8, _62: u8, _63: u8, ) -> Self

Source

impl Simd<u8x64>

pub fn from_slice_unaligned(slice: &[u8]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<usizex1>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: usize) -> Self

Source

impl Simd<usizex1>

pub fn from_slice_unaligned(slice: &[usize]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<usizex2>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: usize, _1: usize) -> Self

Source

impl Simd<usizex2>

pub fn from_slice_unaligned(slice: &[usize]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<usizex4>

pub const ZERO: Self

pub const ONE: Self

pub fn new(_0: usize, _1: usize, _2: usize, _3: usize) -> Self

Source

impl Simd<usizex4>

pub fn from_slice_unaligned(slice: &[usize]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<usizex8>

pub const ZERO: Self

pub const ONE: Self

pub fn new( _0: usize, _1: usize, _2: usize, _3: usize, _4: usize, _5: usize, _6: usize, _7: usize, ) -> Self

Source

impl Simd<usizex8>

pub fn from_slice_unaligned(slice: &[usize]) -> Self

Instantiates a new vector with the values of the slice.

Panics

If slice.len() < Self::LANES.

Source

impl Simd<mask16x1>

pub fn new(_0: bool) -> Self

Source

impl Simd<mask16x2>

pub fn new(_0: bool, _1: bool) -> Self

Source

impl Simd<mask16x4>

pub fn new(_0: bool, _1: bool, _2: bool, _3: bool) -> Self

Source

impl Simd<mask16x8>

pub fn new( _0: bool, _1: bool, _2: bool, _3: bool, _4: bool, _5: bool, _6: bool, _7: bool, ) -> Self

Source

impl Simd<mask16x16>

pub fn new( _0: bool, _1: bool, _2: bool, _3: bool, _4: bool, _5: bool, _6: bool, _7: bool, _8: bool, _9: bool, _10: bool, _11: bool, _12: bool, _13: bool, _14: bool, _15: bool, ) -> Self

Source

impl Simd<mask16x32>

pub fn new( _0: bool, _1: bool, _2: bool, _3: bool, _4: bool, _5: bool, _6: bool, _7: bool, _8: bool, _9: bool, _10: bool, _11: bool, _12: bool, _13: bool, _14: bool, _15: bool, _16: bool, _17: bool, _18: bool, _19: bool, _20: bool, _21: bool, _22: bool, _23: bool, _24: bool, _25: bool, _26: bool, _27: bool, _28: bool, _29: bool, _30: bool, _31: bool, ) -> Self

Source

impl Simd<mask32x1>

pub fn new(_0: bool) -> Self

Source

impl Simd<mask32x2>

pub fn new(_0: bool, _1: bool) -> Self

Source

impl Simd<mask32x4>

pub fn new(_0: bool, _1: bool, _2: bool, _3: bool) -> Self

Source

impl Simd<mask32x8>

pub fn new( _0: bool, _1: bool, _2: bool, _3: bool, _4: bool, _5: bool, _6: bool, _7: bool, ) -> Self

Source

impl Simd<mask32x16>

pub fn new( _0: bool, _1: bool, _2: bool, _3: bool, _4: bool, _5: bool, _6: bool, _7: bool, _8: bool, _9: bool, _10: bool, _11: bool, _12: bool, _13: bool, _14: bool, _15: bool, ) -> Self

Source

impl Simd<mask64x1>

pub fn new(_0: bool) -> Self

Source

impl Simd<mask64x2>

pub fn new(_0: bool, _1: bool) -> Self

Source

impl Simd<mask64x4>

pub fn new(_0: bool, _1: bool, _2: bool, _3: bool) -> Self

Source

impl Simd<mask64x8>

pub fn new( _0: bool, _1: bool, _2: bool, _3: bool, _4: bool, _5: bool, _6: bool, _7: bool, ) -> Self

Source

impl Simd<mask8x1>

pub fn new(_0: bool) -> Self

Source

impl Simd<mask8x2>

pub fn new(_0: bool, _1: bool) -> Self

Source

impl Simd<mask8x4>

pub fn new(_0: bool, _1: bool, _2: bool, _3: bool) -> Self

Source

impl Simd<mask8x8>

pub fn new( _0: bool, _1: bool, _2: bool, _3: bool, _4: bool, _5: bool, _6: bool, _7: bool, ) -> Self

Source

impl Simd<mask8x16>

pub fn new( _0: bool, _1: bool, _2: bool, _3: bool, _4: bool, _5: bool, _6: bool, _7: bool, _8: bool, _9: bool, _10: bool, _11: bool, _12: bool, _13: bool, _14: bool, _15: bool, ) -> Self

Source

impl Simd<mask8x32>

pub fn new( _0: bool, _1: bool, _2: bool, _3: bool, _4: bool, _5: bool, _6: bool, _7: bool, _8: bool, _9: bool, _10: bool, _11: bool, _12: bool, _13: bool, _14: bool, _15: bool, _16: bool, _17: bool, _18: bool, _19: bool, _20: bool, _21: bool, _22: bool, _23: bool, _24: bool, _25: bool, _26: bool, _27: bool, _28: bool, _29: bool, _30: bool, _31: bool, ) -> Self

Source

impl Simd<mask8x64>

pub fn new( _0: bool, _1: bool, _2: bool, _3: bool, _4: bool, _5: bool, _6: bool, _7: bool, _8: bool, _9: bool, _10: bool, _11: bool, _12: bool, _13: bool, _14: bool, _15: bool, _16: bool, _17: bool, _18: bool, _19: bool, _20: bool, _21: bool, _22: bool, _23: bool, _24: bool, _25: bool, _26: bool, _27: bool, _28: bool, _29: bool, _30: bool, _31: bool, _32: bool, _33: bool, _34: bool, _35: bool, _36: bool, _37: bool, _38: bool, _39: bool, _40: bool, _41: bool, _42: bool, _43: bool, _44: bool, _45: bool, _46: bool, _47: bool, _48: bool, _49: bool, _50: bool, _51: bool, _52: bool, _53: bool, _54: bool, _55: bool, _56: bool, _57: bool, _58: bool, _59: bool, _60: bool, _61: bool, _62: bool, _63: bool, ) -> Self

Source

impl Simd<masksizex1>

pub fn new(_0: bool) -> Self

Source

impl Simd<masksizex2>

pub fn new(_0: bool, _1: bool) -> Self

Source

impl Simd<masksizex4>

pub fn new(_0: bool, _1: bool, _2: bool, _3: bool) -> Self

Source

impl Simd<masksizex8>

pub fn new( _0: bool, _1: bool, _2: bool, _3: bool, _4: bool, _5: bool, _6: bool, _7: bool, ) -> Self